#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# original build script from Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://guake-terminal.org/
# source location	 : http://guake-terminal.org/releases/0.4.1/guake-0.4.1.tar.gz
# last revised       : 28.11.2009

softname='guake'
softversion='0.4.1'
packageversion='64.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://guake-terminal.org/releases/$softversion/$softname-$softversion.tar.gz

#  prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/scalable/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
     |-----handy-ruler------------------------------------------------------|
guake: guake - A gnome terminal emulator
guake:
guake: Guake is a drop-down terminal for GNOME Desktop Environment, so you 
guake: just need to press a key to invoke him, and press again to hide. 
guake: Guake supports hotkeys, tabs, background transparent, etc.
guake:
guake:
guake:
guake:
guake: 
guake:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--disable-schemas-install --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make 
make install DESTDIR=$dest

cp ../doinst.sh $dest/install

# gconf stuff
 export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
     # Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
 fi 

# make icon
cp ../guake-48.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Guake
Name=Guake Terminal
Name[pt]=Guake Terminal
Name[pt_BR]=Guake Terminal
Comment=Use the command line in a Quake like terminal
Comment[pt]=Utilizar a linha de comando em um terminal estilo Quake
Comment[pt_BR]=Utilizar a linha de comando em um terminal estilo Quake
Exec=guake
Icon=guake
Categories=Application;Utility;TerminalEmulator;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING TODO ChangeLog INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion
	
	
	mv -v $dest/usr/share/pixmaps/guake/guake.svg $dest/usr/share/icons/scalable/apps/
	
# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild 
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,expat,fontconfig,freetype,glib2,gtk+2,\
libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libpng,libxcb,notify-python,pango,\
pixman,python,xcb-util,xfce-notifyd,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/guake/source/build-guake.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/guake/source/doinst.sh >>$package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/guake/source/guake-48.png >>$package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
